pro foverlay,image,points,roi=roi,psym=psym
;+
; NAME:
;		foverlay
; PURPOSE:
;		Overlay points onto an image.
; CATEGORY:
;		Image Processing
; CALLING SEQUENCE:
;		foverlay,image,points
; INPUTS:
;		image:	Two-dimensional data set onto which points should
;			by overlaid.
;		points: (2,npoints) array of overlay points
; OUTPUTS:
;		none
; KEYWORDS:
;		roi:	Region of interest within the image:
;			roi(0) : minimum x index
;			roi(1) : max x
;			roi(2) : min y
;			roi(3) : max y
; SIDE EFFECTS:
;		redraws screen.  Changes color tables.
; RESTRICTIONS:
;		no error checking: points must fall within image borders
;		if added, roi must fall within image.
;
; REQUIRES:     dgcont_image.pro
;
; PROCEDURE:
;		Rescale the image to leave one color table index free.
;		Make the rest of the color table into a grey ramp and
;		turn the highest index purple.
;		Then calls DGCONT_IMAGE and over plots the points
;		in purple.
; MODIFICATION HISTORY:
;		Written by David G. Grier, AT&T Bell Laboratories, 7/91
;		Completely rewritten DGG, The University of Chicago, 3/93.
;               Add keyword psym, some comments. (Korda, UofC, 05-00)
;-

on_error,2

; Setting color table

nc = !d.table_size
if nc eq 0 then message,'Device has static color tables: cannot adjust'
red = byte(indgen(nc))
green = red
blue = red
green(nc-1) = 0b
tvlct,red,green,blue

m = image < (nc - 2)
x = reform( points(0,*) )
y = reform( points(1,*) )
if keyword_set( roi ) then begin             ;define region of interest
	m = m(roi(0):roi(1),roi(2):roi(3))
	x = x - roi(0)
	y = y - roi(2)
	endif
dgcont_image,m,/aspect,/nocont,/interp       ;display image

if not keyword_set( psym ) then psym = 2     ; if psym not specified, use *

oplot,x,y,psym=psym,color=nc-1               ; display features
end
