;+
; NAME:
;	RSPRETRACK
;
; PURPOSE:
;	 This code is slightly modified from gspretrack written by Gabe Spalding.
;
;    This is function does the following:
;	1) read in .xys filenames, "xfiles"
;	containing information about identified particles
;	-- the x- and y- positions of the particle centroids, along with
;	other "stuff" (hence the name "xys"):
;	feat[0,*] contains the x centroid positions, in pixels.
;	feat[1,*] contains the y centroid positions, in pixels.
;	feat[2,*] contains the integrated brightness of the features.
;	feat[3,*] contains the square of the radius of gyration
;		of the features.
;	feat[4,*] contains the eccentricity, which should be
;		zero for circularly symmetric features and order
;		one for very elongated images.
;	2) Add a "framenumber" to the feature data for each frame
;	3) return the aggregate feature data (over all frames)
;		as an array that can be used by "track.pro"
;
; CATEGORY:
;	features
;
; CALLING SEQUENCE:
;	posns = rspretrack(xfiles)
;
; INPUTS:
;	xfiles: the output of findfile or superff, containing the
;		filenames (including path) for the xys datafiles
;
; OPTIONAL INPUTS (KEYWORD PARAMETERS, which can be abbreviated
;		   to the shortest unique form):
;
; OUTPUTS:
;	posns: an array containing aggregate feature data
;		to be used by track.pro
;
; SIDE EFFECTS:
;
; REQUIRES:
;
; RESTRICTIONS:
;
; MODIFICATION HISTORY:
;	Written by Gabe Spalding, Mar 2003
;-

FUNCTION rspretrack, xfiles

number = N_ELEMENTS(xfiles)   ; number of xys files to be processed
f_ind = number-1
res=fltarr(6)
help, xfiles
FOR i=0,(f_ind) DO BEGIN
print, xfiles[i]
   xys = READ_GDF(xfiles[i])
;   IF (size(xys, /n_dimensions) GT 1) THEN BEGIN
;      index=where(xys[4,*] LT 0.16)
;      xys = xys[*,index]
;   ENDIF ELSE BEGIN
;      IF (xys[4] GE 0.16) THEN xys[0]=-1
;   ENDELSE
; Let's make tracks just for the silica particles:
;   IF (xys[0] NE -1) THEN BEGIN
;      index=where((xys[0,*] GE 50) AND (xys[0,*] LE 680))
;      IF index[0] EQ -1 THEN xys=[-1,-1,-1,-1,-1] $
;      ELSE xys = xys[*,index]
;   ENDIF
   nf =  n_elements(xys[0,*])
   if (xys[0] ne -1) then res = [[res],[xys,fltarr(1,nf)+i]]
print, i
ENDFOR

; return an array that can be used by track.pro
return,res[*,1:*]

END
